@@ -1,7 +1,7 @@
 """Admin classes for the booking app."""
 from django.contrib import admin
 
-from simple_translation.admin import TranslationAdmin
+from hvad.admin import TranslatableAdmin
 
 from . import models
 
@@ -18,5 +18,7 @@ class BookingItemAdmin(admin.ModelAdmin):
 
 
 admin.site.register(models.Booking, BookingAdmin)
+admin.site.register(models.BookingError)
 admin.site.register(models.BookingItem, BookingItemAdmin)
-admin.site.register(models.BookingStatus, TranslationAdmin)
+admin.site.register(models.BookingStatus, TranslatableAdmin)
+admin.site.register(models.ExtraPersonInfo)
