@@ -5,48 +5,34 @@ from django.contrib.contenttypes.models import ContentType
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
-from django_libs.models_mixins import SimpleTranslationMixin
+from hvad.models import TranslatableModel, TranslatedFields
 from international.models import countries
 
 
-class BookingStatus(SimpleTranslationMixin, models.Model):
+class BookingStatus(TranslatableModel):
     """
     Master data containing all booking status.
     For translatable fields check ``BookingStatusTranslation``.
 
     :slug: A unique slug identifier.
 
+    translated:
+    :name: The displayable name for the status.
+
     """
     slug = models.SlugField(
         verbose_name=_('Slug'),
     )
 
-    def __unicode__(self):
-        return self.slug
-
-
-class BookingStatusTranslation(models.Model):
-    """
-    Translatable fields of the ``BookingStatus`` model.
-
-    :name: The name of the status.
-
-    Needed by simple translation:
-    :language: The language of the translation.
-    :status: The status this translation belongs to.
-
-    """
-    name = models.CharField(
-        max_length=128,
-        verbose_name=_('Name'),
+    translations = TranslatedFields(
+        name=models.CharField(
+            verbose_name=_('Name'),
+            max_length=128,
+        )
     )
 
-    # needed by simple translation
-    language = models.CharField(max_length=16)
-    status = models.ForeignKey(BookingStatus)
-
     def __unicode__(self):
-        return self.name
+        return self.safe_translation_getter('name', self.slug)
 
 
 class Booking(models.Model):
@@ -253,6 +239,47 @@ class Booking(models.Model):
                                  self.creation_date)
 
 
+class BookingError(models.Model):
+    """
+    Holds information about an error during a booking process.
+
+    This can be particularly useful, when many of the processes are automated
+    or reliant on a third party app or API. You then can store the returned
+    values directly into this model and have easy access and reference to the
+    actual booking.
+
+    :booking: The booking during this error occurred.
+    :message: The short error message, that you need to store.
+    :details: A more in depth text about the error or any kind of additional
+      information, e.g. a traceback.
+    :date: The time and date this error occured.
+
+    """
+    booking = models.ForeignKey(
+        Booking,
+        verbose_name=_('Booking'),
+    )
+    message = models.CharField(
+        verbose_name=_('Message'),
+        max_length=1000,
+        blank=True,
+    )
+    details = models.TextField(
+        verbose_name=_('Details'),
+        max_length=4000,
+        blank=True,
+    )
+
+    date = models.DateTimeField(
+        verbose_name=_('Date'),
+        auto_now_add=True,
+    )
+
+    def __unicode__(self):
+        return '[{0}] {1} - {2}'.format(self.date, self.booking.booking_id,
+                                        self.message)
+
+
 class BookingItem(models.Model):
     """
     Model to connect a booking with a related object.
